import {
  Component,
  OnInit,
  Inject,
  ViewChild,
  ElementRef
} from '@angular/core';
import {
  MatDialogRef,
  MAT_DIALOG_DATA,
  MatSelectionList,
  MatSelectionListChange,
  MatDrawer
} from '@angular/material';
import { Observable, combineLatest, of } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { map, catchError, take } from 'rxjs/operators';

import * as AppStore from '@app/store';
import * as SyncStore from '@app/store/messenger/sync';

import {
  DialogService,
  ConfirmDialogComponent,
  ConfirmDialogData,
  ConfirmDialogResult,
  SnackBarService,
  AlertDialogComponent,
  AlertDialogResult,
  AlertDialogData
} from '@ucap-webmessenger/ui';
import { GroupDetailData, UserInfo } from '@ucap-webmessenger/protocol-sync';
import {
  DetailResponse,
  MessageType,
  DetailContent,
  DetailReceiver,
  ContentType,
  MessageDetailInfo,
  MessageApiService,
  RetrieveResourceFileRequest,
  CancelRequest
} from '@ucap-webmessenger/api-message';
import { DeviceType, MimeUtil, FileUtil } from '@ucap-webmessenger/core';
import { LoginResponse } from '@ucap-webmessenger/protocol-authentication';
import { NGXLogger } from 'ngx-logger';
import { NativeService, UCAP_NATIVE_SERVICE } from '@ucap-webmessenger/native';
import { MessageStatusCode } from '@ucap-webmessenger/api';
import { MessageEditorComponent } from 'projects/ucap-webmessenger-ui/src/lib/components/message-editor.component';

export interface EditMessageDialogData {
  loginRes: LoginResponse;
  detail?: DetailResponse;
}

// tslint:disable-next-line: no-empty-interface
export interface EditMessageDialogResult {}

export interface DownloadQueueForMessage extends DetailContent {
  downloadType: string;
}

@Component({
  selector: 'app-layout-messenger-edit-message',
  templateUrl: './edit-message.dialog.component.html',
  styleUrls: ['./edit-message.dialog.component.scss']
})
export class EditMessageDialogComponent implements OnInit {
  @ViewChild(MessageEditorComponent, { static: false })
  editor?: MessageEditorComponent;

  constructor(
    public dialogRef: MatDialogRef<
      EditMessageDialogData,
      EditMessageDialogResult
    >,
    @Inject(MAT_DIALOG_DATA) public data: EditMessageDialogData,
    @Inject(UCAP_NATIVE_SERVICE) private nativeService: NativeService,
    private messageApiService: MessageApiService,
    private snackBarService: SnackBarService,
    private logger: NGXLogger,
    private store: Store<any>,
    private dialogService: DialogService
  ) {}

  ngOnInit(): void {}

  getBtnValid() {
    return true;
  }

  onClickChoice(choice: boolean): void {
    this.dialogRef.close();
  }

  onClickTest() {
    console.log(this.editor.getContents());
  }
}
